@@ -15,38 +15,56 @@ from typing import List, Tuple
 import click
 import yaml
 
+from spsdk import SPSDK_DATA_FOLDER
 from spsdk import __version__ as version
-from spsdk.apps.elftosb_helper import RootOfTrustInfo
+from spsdk.apps.elftosb_utils.sb_31_helper import RootOfTrustInfo
 from spsdk.apps.utils import catch_spsdk_error
-from spsdk.crypto import (generate_ecc_private_key, generate_ecc_public_key,
-                          generate_rsa_private_key, generate_rsa_public_key,
-                          save_ecc_private_key, save_ecc_public_key,
-                          save_rsa_private_key, save_rsa_public_key)
+from spsdk.crypto import (
+    generate_ecc_private_key,
+    generate_ecc_public_key,
+    generate_rsa_private_key,
+    generate_rsa_public_key,
+    save_ecc_private_key,
+    save_ecc_public_key,
+    save_rsa_private_key,
+    save_rsa_public_key,
+)
 from spsdk.dat import DebugCredential
 
+NXPKEYGEN_DATA_FOLDER: str = os.path.join(SPSDK_DATA_FOLDER, "nxpkeygen")
+
 logger = logging.getLogger(__name__)
 LOG_LEVEL_NAMES = [name.lower() for name in logging._nameToLevel]
 
 
 @click.group()
-@click.option('-p', '--protocol', 'protocol', type=str, metavar='VERSION', default='1.0',
-              help='Set the protocol version. Default is 1.0 (RSA). ')
-@click.option('-d', '--debug', 'log_level', metavar='LEVEL', default='debug',
-              help=f'Set the level of system logging output. '
-                   f'Available options are: {", ".join(LOG_LEVEL_NAMES)}',
-              type=click.Choice(LOG_LEVEL_NAMES))
-@click.version_option(version, '--version')
+@click.option(
+    "-p",
+    "--protocol",
+    "protocol",
+    type=str,
+    metavar="VERSION",
+    default="1.0",
+    help="Set the protocol version. Default is 1.0 (RSA). ",
+)
+@click.option(
+    "-d",
+    "--debug",
+    "log_level",
+    metavar="LEVEL",
+    default="debug",
+    help=f"Set the level of system logging output. "
+    f'Available options are: {", ".join(LOG_LEVEL_NAMES)}',
+    type=click.Choice(LOG_LEVEL_NAMES),
+)
+@click.version_option(version, "--version")
 @click.pass_context
 def main(ctx: click.Context, protocol: str, log_level: str) -> int:
     """NXP Key Generator Tool."""
     is_rsa, protocol_version = determine_protocol_version(protocol)
     key_param = determine_key_parameters(is_rsa, protocol_version)
 
-    ctx.obj = {
-        'is_rsa': is_rsa,
-        'key_param': key_param,
-        'protocol_version': protocol
-    }
+    ctx.obj = {"is_rsa": is_rsa, "key_param": key_param, "protocol_version": protocol}
 
     logging.basicConfig(level=log_level.upper())
     return 0
@@ -59,15 +77,8 @@ def determine_key_parameters(is_rsa: bool, protocol_version: List[str]) -> objec
     :param protocol_version: protocol version string
     :return: string with keys' parameter
     """
-    rsa_key_sizes = {
-        '0': 2048,
-        '1': 4096
-    }
-    ecc_curves = {
-        '0': 'P-256',
-        '1': 'P-384',
-        '2': 'P-521'
-    }
+    rsa_key_sizes = {"0": 2048, "1": 4096}
+    ecc_curves = {"0": "P-256", "1": "P-384", "2": "P-521"}
     key_param = rsa_key_sizes[protocol_version[1]] if is_rsa else ecc_curves[protocol_version[1]]
     return key_param
 
@@ -78,9 +89,15 @@ def determine_protocol_version(protocol: str) -> Tuple[bool, List[str]]:
     :param protocol: one of the values: '1.0', '1.1', '2.0', '2.1', '2.2'
     :return: is_rsa (true/false), protocol_version
     """
-    assert protocol in ['1.0', '1.1', '2.0', '2.1', '2.2'], "Unsupported protocol was given."
+    assert protocol in [
+        "1.0",
+        "1.1",
+        "2.0",
+        "2.1",
+        "2.2",
+    ], "Unsupported protocol was given."
     protocol_version = protocol.split(".")
-    is_rsa = protocol_version[0] == '1'
+    is_rsa = protocol_version[0] == "1"
     return is_rsa, protocol_version
 
 
@@ -116,12 +133,21 @@ def check_file_exists(path: str, force_overwrite: bool = False) -> bool:  # type
 
 
 @main.command()
-@click.option('--password', 'password', metavar='PASSWORD', help='Password with which the output file will be '
-                                                                 'encrypted. If not provided, the output will be '
-                                                                 'unencrypted.')
-@click.argument('path', type=click.Path(file_okay=True))
-@click.option('--force', is_flag=True, default=False,
-              help="Force overwriting of an existing file. Create destination folder, if doesn't exist already.")
+@click.option(
+    "--password",
+    "password",
+    metavar="PASSWORD",
+    help="Password with which the output file will be "
+    "encrypted. If not provided, the output will be "
+    "unencrypted.",
+)
+@click.argument("path", type=click.Path(file_okay=True))
+@click.option(
+    "--force",
+    is_flag=True,
+    default=False,
+    help="Force overwriting of an existing file. Create destination folder, if doesn't exist already.",
+)
 @click.pass_context
 def genkey(ctx: click.Context, path: str, password: str, force: bool) -> None:
     """Generate key pair for RoT or DCK.
@@ -129,8 +155,8 @@ def genkey(ctx: click.Context, path: str, password: str, force: bool) -> None:
     \b
     PATH    - path where the key pairs will be stored
     """
-    is_rsa = ctx.obj['is_rsa']
-    key_param = ctx.obj['key_param']
+    is_rsa = ctx.obj["is_rsa"]
+    key_param = ctx.obj["key_param"]
     check_destination_dir(path, force)
     check_file_exists(path, force)
 
@@ -141,7 +167,7 @@ def genkey(ctx: click.Context, path: str, password: str, force: bool) -> None:
         pub_key_rsa = generate_rsa_public_key(priv_key_rsa)
         logger.info("Saving RSA key pair...")
         save_rsa_private_key(priv_key_rsa, path, password if password else None)
-        save_rsa_public_key(pub_key_rsa, os.path.splitext(path)[0] + '.pub')
+        save_rsa_public_key(pub_key_rsa, os.path.splitext(path)[0] + ".pub")
     else:
         logger.info("Generating ECC private key...")
         priv_key_ec = generate_ecc_private_key(curve_name=key_param)
@@ -149,22 +175,46 @@ def genkey(ctx: click.Context, path: str, password: str, force: bool) -> None:
         pub_key_ec = generate_ecc_public_key(priv_key_ec)
         logger.info("Saving ECC key pair...")
         save_ecc_private_key(priv_key_ec, path, password if password else None)
-        save_ecc_public_key(pub_key_ec, os.path.splitext(path)[0] + '.pub')
+        save_ecc_public_key(pub_key_ec, os.path.splitext(path)[0] + ".pub")
 
 
 @main.command()
-@click.option('-c', '--config', type=click.File('r'), required=True,
-              help='Specify YAML credential config file.')
-@click.option('-e', '--elf2sb-config', type=click.File('r'), required=False,
-              help='Specify Root Of Trust from configuration file used by elf2sb tool')
-@click.option('--force', is_flag=True, default=False,
-              help="Force overwriting of an existing file. Create destination folder, if doesn't exist already.")
-@click.option('--plugin', type=click.Path(exists=True, file_okay=True), required=False,
-              help='External python file containing a custom SignatureProvider implementation.')
-@click.argument('dc_file_path', metavar='PATH', type=click.Path(file_okay=True))
+@click.option(
+    "-c",
+    "--config",
+    type=click.File("r"),
+    required=True,
+    help="Specify YAML credential config file.",
+)
+@click.option(
+    "-e",
+    "--elf2sb-config",
+    type=click.File("r"),
+    required=False,
+    help="Specify Root Of Trust from configuration file used by elf2sb tool",
+)
+@click.option(
+    "--force",
+    is_flag=True,
+    default=False,
+    help="Force overwriting of an existing file. Create destination folder, if doesn't exist already.",
+)
+@click.option(
+    "--plugin",
+    type=click.Path(exists=True, file_okay=True),
+    required=False,
+    help="External python file containing a custom SignatureProvider implementation.",
+)
+@click.argument("dc_file_path", metavar="PATH", type=click.Path(file_okay=True))
 @click.pass_context
-def gendc(ctx: click.Context, plugin: click.Path, dc_file_path: str, config: click.File,
-          elf2sb_config: click.File, force: bool) -> None:
+def gendc(
+    ctx: click.Context,
+    plugin: click.Path,
+    dc_file_path: str,
+    config: click.File,
+    elf2sb_config: click.File,
+    force: bool,
+) -> None:
     """Generate debug certificate (DC).
 
     \b
@@ -173,13 +223,14 @@ def gendc(ctx: click.Context, plugin: click.Path, dc_file_path: str, config: cli
     if plugin:
         # if a plugin is present simply load it
         # The SignatureProvider will automatically pick up any implementation(s)
-        from importlib.util import spec_from_file_location, module_from_spec
-        spec = spec_from_file_location(name='plugin', location=plugin)  # type: ignore
+        from importlib.util import module_from_spec, spec_from_file_location
+
+        spec = spec_from_file_location(name="plugin", location=plugin)  # type: ignore
         mod = module_from_spec(spec)
         spec.loader.exec_module(mod)  # type: ignore
 
-    is_rsa = ctx.obj['is_rsa']
-    protocol = ctx.obj['protocol_version']
+    is_rsa = ctx.obj["is_rsa"]
+    protocol = ctx.obj["protocol_version"]
     check_destination_dir(dc_file_path, force)
     check_file_exists(dc_file_path, force)
 
@@ -200,9 +251,34 @@ def gendc(ctx: click.Context, plugin: click.Path, dc_file_path: str, config: cli
     dc.sign()
     data = dc.export()
     logger.info("Saving the debug credential to a file...")
-    with open(dc_file_path, 'wb') as f:
+    with open(dc_file_path, "wb") as f:
         f.write(data)
 
+@main.command()
+@click.argument("output", metavar="PATH", type=click.Path())
+@click.option(
+    "-f",
+    "--force",
+    is_flag=True,
+    default=False,
+    help="Force overwriting of an existing file. Create destination folder, if doesn't exist already.",
+)
+def get_gendc_config(output: click.Path, force: bool) -> None:
+    """Generate the template of Debug Credentials YML configuration file.
+
+    \b
+    PATH    - file name path to write template config file
+    """
+    check_destination_dir(str(output), force)
+    check_file_exists(str(output), force)
+
+    with open(os.path.join(NXPKEYGEN_DATA_FOLDER, "template_config.yml"), "r") as file:
+        template = file.read()
+
+    with open(str(output), "w") as file:
+        file.write(template)
+
+    click.echo("The configuration template file has been created.")
 
 @catch_spsdk_error
 def safe_main() -> None:
