@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2020 NXP
+# Copyright 2020-2021 NXP
 #
 # SPDX-License-Identifier: BSD-3-Clause
 """Contains support for BEE encryption for RT10xx devices."""
@@ -53,7 +53,7 @@ class BeeBaseClass:
 
     def info(self) -> str:
         """:return: text description of the instance."""
-        raise NotImplementedError('abstract method')
+        raise NotImplementedError("abstract method")
 
     def update(self) -> None:
         """Updates internal fields of the instance."""
@@ -69,7 +69,7 @@ class BeeBaseClass:
         """:return: binary representation of the region (serialization)."""
         self.update()
         self.validate()
-        return b''
+        return b""
 
     @classmethod
     def parse(cls, data: bytes, offset: int = 0) -> Any:
@@ -81,7 +81,7 @@ class BeeBaseClass:
         :raise ValueError: if size of the data is not sufficient
         """
         if len(data) - offset < cls._size():
-            raise ValueError('Insufficient size of the data')
+            raise ValueError("Insufficient size of the data")
         return 0
 
 
@@ -105,7 +105,7 @@ class BeeFacRegion(BeeBaseClass):
         self.validate()
 
     def __str__(self) -> str:
-        return f'FAC: 0x{self.start_addr:08x}[0x{self.length:x}]'
+        return f"FAC: 0x{self.start_addr:08x}[0x{self.length:x}]"
 
     @property
     def end_addr(self) -> int:
@@ -114,21 +114,29 @@ class BeeFacRegion(BeeBaseClass):
 
     def info(self) -> str:
         """:return: test description of the instance."""
-        return f'FAC(start={hex(self.start_addr)}, length={hex(self.length)}, protected_level={self.protected_level})'
+        return f"FAC(start={hex(self.start_addr)}, length={hex(self.length)}, protected_level={self.protected_level})"
 
     def validate(self) -> None:
         """Validates the configuration of the instance."""
-        assert (self.start_addr & _ENCR_BLOCK_ADDR_MASK == 0) and (self.length & _ENCR_BLOCK_ADDR_MASK == 0)
+        assert (self.start_addr & _ENCR_BLOCK_ADDR_MASK == 0) and (
+            self.length & _ENCR_BLOCK_ADDR_MASK == 0
+        )
         assert 0 <= self.protected_level <= 3
         assert 0 <= self.start_addr < self.end_addr <= 0xFFFFFFFF
 
     def export(self) -> bytes:
         """Exports the binary representation."""
         result = super().export()
-        return result + pack(self._struct_format(), self.start_addr, self.end_addr, self.protected_level, b'\x00' * 20)
+        return result + pack(
+            self._struct_format(),
+            self.start_addr,
+            self.end_addr,
+            self.protected_level,
+            b"\x00" * 20,
+        )
 
     @classmethod
-    def parse(cls, data: bytes, offset: int = 0) -> 'BeeFacRegion':
+    def parse(cls, data: bytes, offset: int = 0) -> "BeeFacRegion":
         """Deserialization.
 
         :param data: binary data to be parsed
@@ -137,14 +145,17 @@ class BeeFacRegion(BeeBaseClass):
         :raise ValueError: if reserved area is non-zero
         """
         super().parse(data, offset)  # check size of the data
-        (start, end, protected_level, _reserved) = unpack_from(BeeFacRegion._struct_format(), data, offset)
-        if _reserved != b'\x00' * 20:
-            raise ValueError('Reserved area is non-zero')
+        (start, end, protected_level, _reserved) = unpack_from(
+            BeeFacRegion._struct_format(), data, offset
+        )
+        if _reserved != b"\x00" * 20:
+            raise ValueError("Reserved area is non-zero")
         return BeeFacRegion(start, end - start, protected_level)
 
 
 class BeeProtectRegionBlockAesMode(Enum):
     """AES mode selection for BEE PRDB encryption."""
+
     ECB = 0
     CTR = 1
 
@@ -153,7 +164,7 @@ class BeeProtectRegionBlock(BeeBaseClass):
     """BEE protect region block (PRDB)."""
 
     # format of the binary representation of the class, used as parameter for struct.pack/unpack methods
-    _FORMAT = '<8I16s32s'
+    _FORMAT = "<8I16s32s"
     # low TAG used in the header
     TAGL = 0x5F474154  # "TAG_"
     # high TAG used in the header
@@ -170,8 +181,12 @@ class BeeProtectRegionBlock(BeeBaseClass):
         """:return: size of the exported binary data in bytes."""
         return cls.SIZE
 
-    def __init__(self, encr_mode: BeeProtectRegionBlockAesMode = BeeProtectRegionBlockAesMode.CTR,
-                 lock_options: int = 0, counter: Optional[bytes] = None):
+    def __init__(
+        self,
+        encr_mode: BeeProtectRegionBlockAesMode = BeeProtectRegionBlockAesMode.CTR,
+        lock_options: int = 0,
+        counter: Optional[bytes] = None,
+    ):
         """Constructor.
 
         :param encr_mode: AES encryption mode
@@ -183,7 +198,9 @@ class BeeProtectRegionBlock(BeeBaseClass):
         self._end_addr = 0xFFFFFFFF  # this is calculated automatically based on FAC regions
         self.mode = encr_mode
         self.lock_options = lock_options
-        self.counter = counter if counter else crypto_backend().random_bytes(12) + b'\x00\x00\x00\x00'
+        self.counter = (
+            counter if counter else crypto_backend().random_bytes(12) + b"\x00\x00\x00\x00"
+        )
 
         # - FAC regions, 1 - 4
         self.fac_regions: List[BeeFacRegion] = list()
@@ -218,10 +235,10 @@ class BeeProtectRegionBlock(BeeBaseClass):
 
     def info(self) -> str:
         """:return: test description of the instance."""
-        result = f'BEE Region Header (start={hex(self._start_addr)}, end={hex(self._end_addr)})\n'
-        result += f'AES Encryption mode: {BeeProtectRegionBlockAesMode.name(self.mode)}\n'
+        result = f"BEE Region Header (start={hex(self._start_addr)}, end={hex(self._end_addr)})\n"
+        result += f"AES Encryption mode: {BeeProtectRegionBlockAesMode.name(self.mode)}\n"
         for fac in self.fac_regions:
-            result += fac.info() + '\n'
+            result += fac.info() + "\n"
         return result
 
     def validate(self) -> None:
@@ -231,9 +248,11 @@ class BeeProtectRegionBlock(BeeBaseClass):
         """
         assert 0 <= self._start_addr <= 0xFFFFFFFF
         assert self._start_addr <= self._end_addr <= 0xFFFFFFFF
-        assert self.mode == BeeProtectRegionBlockAesMode.CTR, 'only AES/CTR encryption mode supported now'  # TODO
+        assert (
+            self.mode == BeeProtectRegionBlockAesMode.CTR
+        ), "only AES/CTR encryption mode supported now"  # TODO
         assert len(self.counter) == 16
-        assert self.counter[-4:] == b'\x00\x00\x00\x00', 'last four bytes must be zero'
+        assert self.counter[-4:] == b"\x00\x00\x00\x00", "last four bytes must be zero"
         assert 0 < self.fac_count <= self.FAC_REGIONS
         for fac in self.fac_regions:
             fac.validate()
@@ -241,24 +260,26 @@ class BeeProtectRegionBlock(BeeBaseClass):
     def export(self) -> bytes:
         """:return: binary representation of the region (serialization)."""
         result = super().export()
-        result += pack(self._struct_format(),
-                       self.TAGL,
-                       self.TAGH,
-                       self.VERSION,
-                       self.fac_count,
-                       self._start_addr,
-                       self._end_addr,
-                       self.mode,
-                       self.lock_options,
-                       self.counter[::-1],  # bytes swapped: reversed order
-                       b'\x00' * 32)
+        result += pack(
+            self._struct_format(),
+            self.TAGL,
+            self.TAGH,
+            self.VERSION,
+            self.fac_count,
+            self._start_addr,
+            self._end_addr,
+            self.mode,
+            self.lock_options,
+            self.counter[::-1],  # bytes swapped: reversed order
+            b"\x00" * 32,
+        )
         for fac in self.fac_regions:
             result += fac.export()
         result = extend_block(result, self.SIZE)
         return result
 
     @classmethod
-    def parse(cls, data: bytes, offset: int = 0) -> 'BeeProtectRegionBlock':
+    def parse(cls, data: bytes, offset: int = 0) -> "BeeProtectRegionBlock":
         """Deserialization.
 
         :param data: binary data to be parsed
@@ -277,15 +298,15 @@ class BeeProtectRegionBlock(BeeBaseClass):
             mode,
             lock_options,
             counter,
-            _reserved_32
+            _reserved_32,
         ) = unpack_from(BeeProtectRegionBlock._struct_format(), data, offset)
         #
         if (tagl != BeeProtectRegionBlock.TAGL) or (tagh != BeeProtectRegionBlock.TAGH):
-            raise ValueError('Invalid tag or unsupported version')
+            raise ValueError("Invalid tag or unsupported version")
         if version != BeeProtectRegionBlock.VERSION:
-            raise ValueError('Unsupported version')
-        if _reserved_32 != b'\x00' * 32:
-            raise ValueError('Reserved area is non-zero')
+            raise ValueError("Unsupported version")
+        if _reserved_32 != b"\x00" * 32:
+            raise ValueError("Reserved area is non-zero")
         #
         result = BeeProtectRegionBlock(mode, lock_options, counter[::-1])
         result._start_addr = start_addr
@@ -308,12 +329,18 @@ class BeeProtectRegionBlock(BeeBaseClass):
         """
         assert len(data) == BEE_ENCR_BLOCK_SIZE
         if self._start_addr <= start_addr < self._end_addr:
-            assert self.mode == BeeProtectRegionBlockAesMode.CTR, 'only AES/CTR encryption mode supported now'
+            assert (
+                self.mode == BeeProtectRegionBlockAesMode.CTR
+            ), "only AES/CTR encryption mode supported now"
             assert len(key) == 16
             for fac in self.fac_regions:
                 if fac.start_addr <= start_addr < fac.end_addr:
                     assert start_addr + len(data) <= fac.end_addr
-                    cntr_key = Counter(self.counter, ctr_value=start_addr >> 4, ctr_byteorder_encoding='big')
+                    cntr_key = Counter(
+                        self.counter,
+                        ctr_value=start_addr >> 4,
+                        ctr_byteorder_encoding="big",
+                    )
                     return crypto_backend().aes_ctr_encrypt(key, data, cntr_key.value)
         return data
 
@@ -357,7 +384,7 @@ class BeeKIB(BeeBaseClass):
         return result + pack(self._struct_format(), self.kib_key, self.kib_iv)
 
     @classmethod
-    def parse(cls, data: bytes, offset: int = 0) -> 'BeeKIB':
+    def parse(cls, data: bytes, offset: int = 0) -> "BeeKIB":
         """Deserialization.
 
         :param data: binary data to be parsed
@@ -382,15 +409,21 @@ class BeeRegionHeader(BeeBaseClass):
     @classmethod
     def _struct_format(cls) -> str:
         """:raise AssertionError: it is not expected to called for the class."""
-        raise AssertionError('This method is not expected to be used for this class, format depends on its fields')
+        raise AssertionError(
+            "This method is not expected to be used for this class, format depends on its fields"
+        )
 
     @classmethod
     def _size(cls) -> int:
         """:return: size of the exported binary data in bytes."""
         return cls.SIZE
 
-    def __init__(self, prdb: Optional[BeeProtectRegionBlock] = None, sw_key: Optional[bytes] = None,
-                 kib: Optional[BeeKIB] = None):
+    def __init__(
+        self,
+        prdb: Optional[BeeProtectRegionBlock] = None,
+        sw_key: Optional[bytes] = None,
+        kib: Optional[BeeKIB] = None,
+    ):
         """Constructor.
 
         :param prdb: protect region block; None to use default
@@ -415,9 +448,9 @@ class BeeRegionHeader(BeeBaseClass):
 
     def info(self) -> str:
         """:return: test description of the instance."""
-        result = 'BEE Region Header\n'
-        result += f'- KIB: {self._kib.info()}'
-        result += f'- PRDB: {self._prdb.info()}'
+        result = "BEE Region Header\n"
+        result += f"- KIB: {self._kib.info()}"
+        result += f"- PRDB: {self._prdb.info()}"
         return result
 
     def sw_key_fuses(self) -> Sequence[int]:
@@ -427,7 +460,7 @@ class BeeRegionHeader(BeeBaseClass):
         """
         result = list()
         for pos in range(16, 0, -4):
-            result.append(unpack_from(">I", self._sw_key[pos - 4:pos])[0])
+            result.append(unpack_from(">I", self._sw_key[pos - 4 : pos])[0])
         return result
 
     def update(self) -> None:
@@ -454,21 +487,21 @@ class BeeRegionHeader(BeeBaseClass):
         result = super().export()
         # KIB
         kib_data = self._kib.export()
-        dbg_info.append_binary_section('BEE-KIB (non-crypted)', kib_data)
+        dbg_info.append_binary_section("BEE-KIB (non-crypted)", kib_data)
         aes = AES.new(self._sw_key, AES.MODE_ECB)
         result += aes.encrypt(kib_data)
         # padding
         result = extend_block(result, self.PRDB_OFFSET)
         # PRDB
         prdb_data = self._prdb.export()
-        dbg_info.append_binary_section('BEE-PRDB (non-crypted)', prdb_data)
+        dbg_info.append_binary_section("BEE-PRDB (non-crypted)", prdb_data)
         aes = AES.new(self._kib.kib_key, AES.MODE_CBC, self._kib.kib_iv)
         result += aes.encrypt(prdb_data)
         # padding
         return extend_block(result, self.SIZE)
 
     @classmethod
-    def parse(cls, data: bytes, offset: int = 0, sw_key: bytes = b'') -> 'BeeRegionHeader':
+    def parse(cls, data: bytes, offset: int = 0, sw_key: bytes = b"") -> "BeeRegionHeader":
         """Deserialization.
 
         :param data: binary data to be parsed
@@ -479,10 +512,12 @@ class BeeRegionHeader(BeeBaseClass):
         super().parse(data, offset)  # check size of the input data
         assert len(sw_key) == 16
         aes = AES.new(sw_key, AES.MODE_ECB)
-        decr_data = aes.decrypt(data[offset:offset + BeeKIB._size()])
+        decr_data = aes.decrypt(data[offset : offset + BeeKIB._size()])
         kib = BeeKIB.parse(decr_data)
         aes = AES.new(kib.kib_key, AES.MODE_CBC, kib.kib_iv)
-        decr_data = aes.decrypt(data[offset + cls.PRDB_OFFSET:offset + cls.PRDB_OFFSET + BeeProtectRegionBlock.SIZE])
+        decr_data = aes.decrypt(
+            data[offset + cls.PRDB_OFFSET : offset + cls.PRDB_OFFSET + BeeProtectRegionBlock.SIZE]
+        )
         prdb = BeeProtectRegionBlock.parse(decr_data)
         result = cls(prdb, sw_key, kib)
         result.validate()
