@@ -1,14 +1,27 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2019-2020 NXP
+# Copyright 2019-2021 NXP
 #
 # SPDX-License-Identifier: BSD-3-Clause
 """SB31 module of sbfile."""
 
-from spsdk.sbfile.sb31.commands import CmdErase, CmdLoad, CmdExecute, CmdCall, CmdProgFuses, CmdProgIfr, \
-    CmdSectionHeader, CmdLoadCmac, CmdLoadHashLocking, CmdCopy, CmdFillMemory, parse_command, CmdLoadKeyBlob, \
-    CmdConfigureMemory
+from spsdk.sbfile.sb31.commands import (
+    CmdErase,
+    CmdLoad,
+    CmdExecute,
+    CmdCall,
+    CmdProgFuses,
+    CmdProgIfr,
+    CmdSectionHeader,
+    CmdLoadCmac,
+    CmdLoadHashLocking,
+    CmdCopy,
+    CmdFillMemory,
+    parse_command,
+    CmdLoadKeyBlob,
+    CmdConfigureMemory,
+)
 from spsdk.sbfile.sb31.constants import EnumCmdTag
 
 __all__ = [
