@@ -7,17 +7,22 @@
 
 """Module for cryptographic utilities."""
 
-from .common import matches_key_and_cert, crypto_backend, Counter, serialize_ecc_signature
+from .common import (
+    matches_key_and_cert,
+    crypto_backend,
+    Counter,
+    serialize_ecc_signature,
+)
 from .abstract import BackendClass
 from .cert_blocks import CertBlockV2, CertBlockV31, CertBlock
 from .certificate import Certificate
 from .otfad import KeyBlob, Otfad
 
 __all__ = [
-    'matches_key_and_cert',
-    'crypto_backend',
-    'Counter',
-    'BackendClass',
-    'CertBlockV2',
-    'Certificate'
+    "matches_key_and_cert",
+    "crypto_backend",
+    "Counter",
+    "BackendClass",
+    "CertBlockV2",
+    "Certificate",
 ]
