@@ -7,10 +7,12 @@
 """Miscellaneous functions used throughout the SPSDK."""
 import contextlib
 import os
+import re
 from typing import Callable, Iterable, Iterator, Optional, TypeVar, List, Union
+from math import ceil
 
 # for generics
-T = TypeVar('T')  # pylint: disable=invalid-name
+T = TypeVar("T")  # pylint: disable=invalid-name
 
 
 def align(number: int, alignment: int = 4) -> int:
@@ -35,13 +37,14 @@ def align_block(data: bytes, alignment: int = 4, padding: int = 0) -> bytes:
     assert isinstance(data, bytes)
     assert alignment > 0
     assert -1 <= padding <= 255
-    curr_size = len(data)
-    num_padding = align(curr_size, alignment) - curr_size
+    current_size = len(data)
+    num_padding = align(current_size, alignment) - current_size
     if not num_padding:
         return data
     if padding == -1:
         # pylint: disable=import-outside-toplevel
         from spsdk.utils.crypto.common import crypto_backend
+
         return data + crypto_backend().random_bytes(num_padding)
     return data + bytes([padding]) * num_padding
 
@@ -59,9 +62,9 @@ def extend_block(data: bytes, length: int, padding: int = 0) -> bytes:
     :param padding: 8-bit value value to be used as a padding
     :return: block extended with padding
     """
-    curr_len = len(data)
-    assert length >= curr_len
-    num_padding = length - curr_len
+    current_len = len(data)
+    assert length >= current_len
+    num_padding = length - current_len
     if not num_padding:
         return data
     return data + bytes([padding]) * num_padding
@@ -87,7 +90,7 @@ def load_binary(*args: str) -> bytes:
         All the fields together represents absolute path to the file
     :return: content of the binary file as bytes
     """
-    data = load_file(*args, mode='rb')
+    data = load_file(*args, mode="rb")
     assert isinstance(data, bytes)
     return data
 
@@ -102,12 +105,12 @@ def load_text(*path_segments: str) -> str:
         All the fields together represents absolute path to the file
     :return: content of the binary file as bytes
     """
-    text = load_file(*path_segments, mode='r')
+    text = load_file(*path_segments, mode="r")
     assert isinstance(text, str)
     return text
 
 
-def load_file(*path_segments: str, mode: str = 'r') -> Union[str, bytes]:
+def load_file(*path_segments: str, mode: str = "r") -> Union[str, bytes]:
     """Loads a file into bytes.
 
     :param path_segments: list that consists of:
@@ -124,7 +127,7 @@ def load_file(*path_segments: str, mode: str = 'r') -> Union[str, bytes]:
         return f.read()
 
 
-def write_file(data: Union[str, bytes], *path_segments: str, mode: str = 'w') -> int:
+def write_file(data: Union[str, bytes], *path_segments: str, mode: str = "w") -> int:
     """Writes data into a file.
 
     :param data: data to write
@@ -165,7 +168,7 @@ class DebugInfo:
     """
 
     @classmethod
-    def disabled(cls) -> 'DebugInfo':
+    def disabled(cls) -> "DebugInfo":
         """Return an instance of DebugInfo with disabled message collecting."""
         return DebugInfo(enabled=False)
 
@@ -195,15 +198,15 @@ class DebugInfo:
 
         :param name: of the section
         """
-        self.append(f'[{name}]')
+        self.append(f"[{name}]")
 
     def append_hex_data(self, data: bytes) -> None:
         """Append binary data in HEX form.
 
         :param data: to be logged
         """
-        self.append('hex=' + data.hex())
-        self.append('len=' + str(len(data)) + '=' + hex(len(data)))
+        self.append("hex=" + data.hex())
+        self.append("len=" + str(len(data)) + "=" + hex(len(data)))
 
     def append_binary_section(self, section_name: str, data: bytes) -> None:
         """Append section and binary data.
@@ -221,7 +224,7 @@ class DebugInfo:
         :param data: binary data (up to 8 bytes)
         """
         assert len(data) <= 16
-        self.append(data_name + '=' + data.hex())
+        self.append(data_name + "=" + data.hex())
 
     @property
     def lines(self) -> Iterable[str]:
@@ -233,3 +236,154 @@ class DebugInfo:
     def info(self) -> str:
         """:return: multi-line text with log; empty string if nothing logged or log disabled."""
         return "\n".join(self.lines)
+
+
+def format_value(value: int, size: int, delimeter: str = "_", use_prefix: bool = True) -> str:
+    """Convert the 'value' into either BIN or HEX string, depending on 'size'.
+
+    if 'size' is divisible by 8, function returns HEX, BIN otherwise
+    digits in result string are grouped by 4 using 'delimeter' (underscore)
+    """
+    padding = size if size % 8 else (size // 8) * 2
+    infix = "b" if size % 8 else "x"
+    parts = re.findall(".{1,4}", f"{value:0{padding}{infix}}"[::-1])
+    rev = delimeter.join(parts)[::-1]
+    prefix = f"0{infix}" if use_prefix else ""
+    return f"{prefix}{rev}"
+
+
+def get_bytes_cnt_of_int(value: int, align_to_2n: bool = True) -> int:
+    """Returns count of bytes needed to store handled integer.
+
+    :param value: Input integer value.
+    :param align_to_2n: The result will be aligned to standard sizes 1,2,4,8,12,16,20.
+    :return: Number of bytes needed to store integer.
+    """
+    cnt = 0
+    if value == 0:
+        return 1
+
+    while value != 0:
+        value >>= 8
+        cnt += 1
+
+    if align_to_2n and cnt > 2:
+        cnt = int(ceil(cnt / 4)) * 4
+
+    return cnt
+
+
+def value_to_int(value: Union[bytes, bytearray, int, str], default: int = None) -> int:
+    """Function loads value from lot of formats to integer.
+
+    :param value: Input value.
+    :param default: Default Value in case of invalid input.
+    :return: Value in Integer.
+    :raise TypeError: Unsupported input type.
+    """
+    if isinstance(value, int):
+        return value
+
+    if isinstance(value, (bytes, bytearray)):
+        return int.from_bytes(value, "big")
+
+    if isinstance(value, str) and value != "":
+        # Remove possible underscore in HEX format
+        not_decimal = value.find("_") >= 0
+        value = value.replace("_", "")
+        value = value.replace("b'", "0b")
+        if value.lower().startswith("0x"):
+            return int(value, 16)
+        if value.lower().startswith("0b"):
+            return int(value, 2)
+        if value.isdecimal() and not not_decimal:
+            return int(value)
+        if value[0] != "-":
+            try:
+                # try to decode hex string without '0x' prefix
+                return int(value, 16)
+            except:  # pylint: disable=bare-except
+                pass
+
+    if default is not None:
+        return default
+    raise TypeError(f"Invalid input number type({type(value)}) with value ({value})")
+
+
+def value_to_bytes(value: Union[bytes, bytearray, int, str], align_to_2n: bool = True) -> bytes:
+    """Function loads value from lot of formats.
+
+    :param value: Input value.
+    :param align_to_2n: When is set, the function aligns length of return array to 1,2,4,8,12 etc.
+    :return: Value in bytes.
+    """
+    if isinstance(value, bytes):
+        return value
+
+    if isinstance(value, bytearray):
+        return bytes(value)
+
+    value = value_to_int(value)
+    return value.to_bytes(get_bytes_cnt_of_int(value, align_to_2n), "big")
+
+
+def value_to_bool(value: Union[bool, int, str]) -> bool:
+    """Function decode bool value from various formats.
+
+    :param value: Input value.
+    :return: Boolean value.
+    :raise TypeError: Unsupported input type.
+    """
+    if isinstance(value, bool):
+        return value
+
+    if isinstance(value, int):
+        return bool(value)
+
+    if isinstance(value, str):
+        return value in ("True", "T", "1")
+
+    raise TypeError(f"Invalid input Boolean type({type(value)}) with value ({value})")
+
+
+def reverse_bytes_in_longs(arr: bytes) -> bytes:
+    """The function reverse byte order in longs from input bytes.
+
+    :param arr: Input array.
+    :return: New array with reversed bytes.
+    :raises ValueError: Raises when invalid value is in input.
+    """
+    arr_len = len(arr)
+    if arr_len % 4 != 0:
+        raise ValueError("The input array is not in modulo 4!")
+
+    result = bytearray()
+
+    for x in range(0, arr_len, 4):
+        word = bytearray(arr[x : x + 4])
+        word.reverse()
+        result.extend(word)
+    return bytes(result)
+
+
+def change_endianism(bin_data: bytes) -> bytes:
+    """Convert binary format used in files to binary used in register object.
+
+    :param bin_data: input binary array.
+    :return: Converted array (practically little to big endianism).
+    :raises ValueError: Invalid value on input.
+    """
+    data = bytearray(bin_data)
+    length = len(data)
+    if length == 1:
+        return data
+
+    if length == 2:
+        data.reverse()
+        return data
+
+    # The length of 24 bits is not supported yet
+    if length == 3:
+        raise ValueError("Unsupported length (3) for change endianism.")
+
+    return reverse_bytes_in_longs(data)
