@@ -8,19 +8,18 @@
 """Module defining a USB filtering class."""
 import platform
 import re
-
-from typing import Dict, Tuple, Any
+from typing import Any, Dict, Tuple
 
 
 class USBDeviceFilter:
-    """USB Device Filtering class.
+    """Generic USB Device Filtering class.
 
     Create a filtering instance. This instance holds the USB ID you are insterested
     in during USB HID device search and allows you to compare, whether
     provided USB HID object is the one you are insterested in.
     The allowed format of `usb_id` string is following:
 
-    vid - vendor ID. String holding hex or dec number.
+    vid or pid - vendor ID or product ID. String holding hex or dec number.
     Hex number must be preceded by 0x or 0X. Number of characters after 0x is
     1 - 4. Mixed upper & lower case letters is allowed. e.g. "0xaB12", "0XAB12",
     "0x1", "0x0001".
@@ -30,6 +29,11 @@ class USBDeviceFilter:
     lead to zero results. Leading zeros are not allowed e.g. 0001. This will
     result as invalid match.
 
+    The user may provide a single number as usb_id. In such a case the number
+    may represent either VID or PID. By default, the filter expects this number
+    to be a VID. In rare cases the user may want to filter based on PID.
+    Initialize the `search_by_pid` parameter to True in such cases.
+
     vid/pid - string of vendor ID & product ID separated by ':' or ','
     Same rules apply to the number format as in VID case, except, that the
     string consists of two numbers separated by ':' or ','. It's not allowed
@@ -37,8 +41,6 @@ class USBDeviceFilter:
     Valid vid/pid strings:
     "0x12aB:0xabc", "1,99999"
 
-    device name: see USB_DEVICES
-
     Windows specific:
     instance ID - String in following format "HID\\VID_<HEX>&PID_<HEX>\\<instance_id>",
     see instance ID in device manager under Windows OS.
@@ -68,47 +70,37 @@ class USBDeviceFilter:
     So the 'usb_id' name should be 'SE Blank RT Family @14200000' and the filter should be able to
     filter out such device.
     """
-    # match anything starting with 0x or 0X followed by 0-9 or a-f or
-    # match either 0 or decimal number not starting with zero
-    __vid_regex = "0[xX][0-9a-fA-F]{1,4}|0|[1-9][0-9]{0,4}"
-    # same as above, except it's a combination of two numbers separated by : or ,
-    __vid_pid_regex = "0[xX][0-9a-fA-F]{1,4}(,|:)0[xX][0-9a-fA-F]{1,4}|(0|[1-9][0-9]{0,4})(,|:)(0|[1-9][0-9]{0,4})"
 
-    def __init__(self, usb_id: str = None, nxp_device_names: Dict[str, Tuple[int, int]] = None):
+    def __init__(
+        self,
+        usb_id: str = None,
+        search_by_pid: bool = False,
+    ):
         """Initialize the USB Device Filtering.
 
         :param usb_id: usb_id string
-        :param nxp_device_names: Dictionary holding NXP device vid/pid {"device_name": [vid(int), pid(int)]}
+        :param search_by_pid: if true, expects usb_id to be a PID number, VID otherwise.
         """
         self.usb_id = usb_id
-        self.nxp_device_names = nxp_device_names or {}
-
-    @staticmethod
-    def get_vid_regex() -> str:
-        """Returns the default VID regular expression."""
-        return USBDeviceFilter.__vid_regex
-
-    @staticmethod
-    def get_vid_pid_regex() -> str:
-        """Returns the default VID/PID regular expression."""
-        return USBDeviceFilter.__vid_pid_regex
+        self.search_by_pid = search_by_pid
 
     def compare(self, usb_device_object: Any) -> bool:
         """Compares the internal `usb_id` with provided `usb_device_object`.
 
+        The provided USB ID during initialization may be VID or PID, VID/PID pair,
+        or a path. See private methods for details.
+
         :param usb_device_object: hidapi USB HID device object
 
         :return: True on match, False otherwise
         """
-        vid_regex = self.get_vid_regex()
-        vid_pid_regex = self.get_vid_pid_regex()
         vendor_id = usb_device_object["vendor_id"]
         product_id = usb_device_object["product_id"]
 
         # the hidapi holds the path as bytes, so we convert it to string
-        usb_path = usb_device_object["path"].decode('utf-8')
+        usb_path = usb_device_object["path"].decode("utf-8")
 
-        if platform.system() == 'Windows':
+        if platform.system() == "Windows":
             # On WIN, the user has an instance ID (+ the tool expects following format):
             # 'HID\\VID_1FC9&PID_0130\\6&3B9928A5&0&0000'
             # However, the path has following format:
@@ -116,10 +108,10 @@ class USBDeviceFilter:
             # There is a pattern, which matches, so we take the path and modify it
             # to match the instance ID format. We convert the path to upper case and
             # replace the hash sign with backslash
-            #usb_path = usb_path.upper()
-            usb_path = usb_path.replace('#', '\\')
+            # usb_path = usb_path.upper()
+            usb_path = usb_path.replace("#", "\\")
 
-        if platform.system() == 'Linux':
+        if platform.system() == "Linux":
             # The user input is expected in form of <dec_num>#<dec_num>. So we
             # convert the path returned by HID API into this form so we can
             # compare it
@@ -129,26 +121,133 @@ class USBDeviceFilter:
         # Determine, whether given device matches one of the expected criterion
         if self.usb_id is None:
             return True
-        elif self.usb_id.casefold() in usb_path.casefold() and len(self.usb_id) > 0:
-            # we check the len of usb_id, because usb_id = "" is considered
-            # to be always in the string returning True, which is not expected
-            # behaviour
-            # the provided usb string id fully matches the instance ID
+
+        if self._is_path(usb_path=usb_path):
+            return True
+
+        if self._is_vid_or_pid(vid=vendor_id, pid=product_id):
+            return True
+
+        if self._is_vid_pid(vid=vendor_id, pid=product_id):
             return True
-        elif re.fullmatch(vid_regex, self.usb_id) is not None:
-            # the string corresponds to the vid specification, check a match
-            if int(self.usb_id, 0) == vendor_id:
-                return True
-        elif re.fullmatch(vid_pid_regex, self.usb_id):
-            # the string corresponds to the vid/pid specification, check a match
-            vid_pid = re.split(":|,", self.usb_id)
-            if vendor_id == int(vid_pid[0], 0) and product_id == int(vid_pid[1], 0):
-                return True
-        elif self.usb_id in self.nxp_device_names:
-            vid, pid = self.nxp_device_names[self.usb_id]
-            if vendor_id == vid and product_id == pid:
-                return True
-        else:
-            return False
 
         return False
+
+    def _is_path(self, usb_path: str) -> bool:
+        """Compares the internal usb_id with provided path.
+
+        If the path is a substring of the usb_id, this is considered as a match
+        and True is returned.
+
+        :param usb_path: path to be compared with usd_id.
+        :return: true on a match, false otherwise.
+        """
+        # we check the len of usb_id, because usb_id = "" is considered
+        # to be always in the string returning True, which is not expected
+        # behaviour
+        # the provided usb string id fully matches the instance ID
+        usb_id = self.usb_id or ""
+        if usb_id.casefold() in usb_path.casefold() and len(usb_id) > 0:
+            return True
+
+        return False
+
+    def _is_vid_or_pid(self, vid: int, pid: int) -> bool:
+        # match anything starting with 0x or 0X followed by 0-9 or a-f or
+        # match either 0 or decimal number not starting with zero
+        # this regex is the same for vid and pid => xid
+        xid_regex = "0[xX][0-9a-fA-F]{1,4}|0|[1-9][0-9]{0,4}"
+        usb_id = self.usb_id or ""
+        if re.fullmatch(xid_regex, usb_id) is not None:
+            # the string corresponds to the vid/pid specification, check a match
+            if self.search_by_pid:
+                if int(usb_id, 0) == pid:
+                    return True
+            else:
+                if int(usb_id, 0) == vid:
+                    return True
+
+        return False
+
+    def _is_vid_pid(self, vid: int, pid: int) -> bool:
+        """If usb_id corresponds to VID/PID pair, comapres it with provided vid/pid.
+
+        :param vid: vendor ID to compare.
+        :param pid: product ID to compare.
+        :return: true on a match, false otherwise.
+        """
+        # match anything starting with 0x or 0X followed by 0-9 or a-f or
+        # match either 0 or decimal number not starting with zero
+        # Above pattern is combined to match a pair corresponding to vid/pid.
+        vid_pid_regex = "0[xX][0-9a-fA-F]{1,4}(,|:)0[xX][0-9a-fA-F]{1,4}|(0|[1-9][0-9]{0,4})(,|:)(0|[1-9][0-9]{0,4})"
+        usb_id = self.usb_id or ""
+        if re.fullmatch(vid_pid_regex, usb_id):
+            # the string corresponds to the vid/pid specification, check a match
+            vid_pid = re.split(":|,", usb_id)
+            if vid == int(vid_pid[0], 0) and pid == int(vid_pid[1], 0):
+                return True
+
+        return False
+
+
+class NXPUSBDeviceFilter(USBDeviceFilter):
+    """NXP Device Filtering class.
+
+    Extension of the generic USB device filter class to support filtering
+    based on NXP devices. Modifies the way, how single number is handled.
+    By default, if single value is provided, it's content is expected to be VID.
+    However, legacy tooling were expecting PID, so from this perspective if
+    a single number is provided, we expect that VID is out of range NXP_VIDS.
+    """
+
+    NXP_VIDS = [0x1FC9, 0x15A2]
+
+    def __init__(
+        self,
+        usb_id: str = None,
+        nxp_device_names: Dict[str, Tuple[int, int]] = None,
+    ):
+        """Initialize the USB Device Filtering.
+
+        :param usb_id: usb_id string
+        :param nxp_device_names: Dictionary holding NXP device vid/pid {"device_name": [vid(int), pid(int)]}
+        """
+        super().__init__(usb_id=usb_id, search_by_pid=True)
+        self.nxp_device_names = nxp_device_names or {}
+
+    def compare(self, usb_device_object: Any) -> bool:
+        """Compares the internal `usb_id` with provided `usb_device_object`.
+
+        Extends the comparison by USB names - dictionary of device name and
+        corresponding VID/PID.
+
+        :param usb_device_object: hidapi USB HID device object
+
+        :return: True on match, False otherwise
+        """
+        vendor_id = usb_device_object["vendor_id"]
+        product_id = usb_device_object["product_id"]
+
+        is_valid_id = super().compare(usb_device_object=usb_device_object)
+
+        if is_valid_id:
+            return True
+
+        if self._is_nxp_device_name(vendor_id, product_id):
+            return True
+
+        return False
+
+    def _is_vid_or_pid(self, vid: int, pid: int) -> bool:
+        if vid in NXPUSBDeviceFilter.NXP_VIDS:
+            if True == super()._is_vid_or_pid(vid, pid):
+                return True
+
+        return False
+
+    def _is_nxp_device_name(self, vid: int, pid: int) -> bool:
+        if self.usb_id in self.nxp_device_names:
+            vendor_id, product_id = self.nxp_device_names[self.usb_id]
+            if vendor_id == vid and product_id == pid:
+                return True
+        return False
